Extracts bounded W3C trace context from request _meta without changing it.
Invalid values are omitted from the extracted context. tracestate is only
used with a valid traceparent, as required by W3C Trace Context. Applications
that need the original metadata can read Snodo.Context.metadata.
Summary
Functions
Validates the named client option and returns protocol-native metadata.
Returns valid trace fields from a request metadata map.